@@ -149,12 +149,27 @@ def f_info(args: argparse.Namespace):
 
 
 def f_clone(args: argparse.Namespace):
+
+    if args.dry_run:
+        if args.from_file:
+            for url, repo_name, abs_path in utils.parse_clone_config(args.clonee):
+                print(f"git clone {url} {abs_path}")
+        else:
+            print(f"git clone {args.clonee}")
+        return
+
     if args.directory:
         path = args.directory
     else:
         path = Path.cwd()
+
     if not args.from_file:
         subprocess.run(["git", "clone", args.clonee], cwd=path)
+        # add the cloned repo to gita; group is also supported
+        cloned_path = os.path.join(path, args.clonee.split("/")[-1].split(".")[0])
+        args.paths = [cloned_path]
+        args.recursive = args.auto_group = args.bare = args.skip_submodule = False
+        f_add(args)
         return
 
     if args.preserve_path:
@@ -169,9 +184,15 @@ def f_clone(args: argparse.Namespace):
         )
 
 
-def f_freeze(_):
-    # TODO: filter context
+def f_freeze(args):
     repos = utils.get_repos()
+    ctx = utils.get_context()
+    if args.group is None and ctx:
+        args.group = ctx.stem
+    group_repos = None
+    if args.group:  # only display repos in this group
+        group_repos = utils.get_groups()[args.group]["repos"]
+        repos = {k: repos[k] for k in group_repos if k in repos}
     seen = {""}
     for name, prop in repos.items():
         path = prop["path"]
@@ -460,6 +481,12 @@ def main(argv=None):
         description="print all repo information",
         help="print all repo information",
     )
+    p_freeze.add_argument(
+        "-g",
+        "--group",
+        choices=utils.get_groups(),
+        help="freeze repos in the specified group",
+    )
     p_freeze.set_defaults(func=f_freeze)
 
     p_clone = subparsers.add_parser(
@@ -474,12 +501,6 @@ def main(argv=None):
         "--directory",
         help="Change to DIRECTORY before doing anything.",
     )
-    p_clone.add_argument(
-        "-f",
-        "--from-file",
-        action="store_true",
-        help="If set, clone repos in a config file rendered from `gita freeze`",
-    )
     p_clone.add_argument(
         "-p",
         "--preserve-path",
@@ -487,6 +508,25 @@ def main(argv=None):
         action="store_true",
         help="clone repo(s) in their original paths",
     )
+    p_clone.add_argument(
+        "-n",
+        "--dry-run",
+        action="store_true",
+        help="If set, show command without execution",
+    )
+    xgroup = p_clone.add_mutually_exclusive_group()
+    xgroup.add_argument(
+        "-g",
+        "--group",
+        choices=utils.get_groups(),
+        help="If set, add repo to the specified group after cloning, otherwise add to gita without group.",
+    )
+    xgroup.add_argument(
+        "-f",
+        "--from-file",
+        action="store_true",
+        help="If set, clone repos in a config file rendered from `gita freeze`",
+    )
     p_clone.set_defaults(func=f_clone)
 
     p_rename = subparsers.add_parser(
