@@ -71,6 +71,7 @@ class TestLsLl:
         """
         functional test
         """
+
         # avoid modifying the local configuration
         def side_effect(input, _=None):
             return tmp_path / f"{input}.txt"
@@ -129,18 +130,21 @@ class TestLsLl:
         [
             (
                 PATH_FNAME,
-                "repo1 cmaster dsu\x1b[0m msg \nrepo2 cmaster dsu\x1b[0m msg \nxxx   cmaster dsu\x1b[0m msg \n",
+                "repo1 \x1b[31mmaster     [*+?⇕] \x1b[0m msg \nrepo2 \x1b[31mmaster     [*+?⇕] \x1b[0m msg \nxxx   \x1b[31mmaster     [*+?⇕] \x1b[0m msg \n",
             ),
             (PATH_FNAME_EMPTY, ""),
             (
                 PATH_FNAME_CLASH,
-                "repo1 cmaster dsu\x1b[0m msg \nrepo2 cmaster dsu\x1b[0m msg \n",
+                "repo1 \x1b[31mmaster     [*+?⇕] \x1b[0m msg \nrepo2 \x1b[31mmaster     [*+?⇕] \x1b[0m msg \n",
             ),
         ],
     )
     @patch("gita.utils.is_git", return_value=True)
     @patch("gita.info.get_head", return_value="master")
-    @patch("gita.info._get_repo_status", return_value=("d", "s", "u", "c"))
+    @patch(
+        "gita.info._get_repo_status",
+        return_value=("dirty", "staged", "untracked", "diverged"),
+    )
     @patch("gita.info.get_commit_msg", return_value="msg")
     @patch("gita.info.get_commit_time", return_value="")
     @patch("gita.common.get_config_fname")
@@ -185,6 +189,7 @@ def test_clone_with_url(mock_run):
     args.preserve_path = None
     args.directory = "/home/xxx"
     args.from_file = False
+    args.dry_run = False
     __main__.f_clone(args)
     cmds = ["git", "clone", args.clonee]
     mock_run.assert_called_once_with(cmds, cwd=args.directory)
@@ -203,6 +208,7 @@ def test_clone_with_config_file(*_):
     args.preserve_path = False
     args.directory = None
     args.from_file = True
+    args.dry_run = False
     __main__.f_clone(args)
     mock_run = utils.run_async.mock
     assert mock_run.call_count == 1
@@ -223,6 +229,7 @@ def test_clone_with_preserve_path(*_):
     args.directory = None
     args.from_file = True
     args.preserve_path = True
+    args.dry_run = False
     __main__.f_clone(args)
     mock_run = utils.run_async.mock
     assert mock_run.call_count == 1
@@ -527,7 +534,9 @@ class TestInfo:
         args.info_cmd = None
         __main__.f_info(args)
         out, err = capfd.readouterr()
-        assert "In use: branch,commit_msg,commit_time\nUnused: path\n" == out
+        assert (
+            "In use: branch,commit_msg,commit_time\nUnused: branch_name,path\n" == out
+        )
         assert err == ""
 
     @patch("gita.common.get_config_fname")
@@ -560,7 +569,7 @@ def test_set_color(mock_get_fname, tmpdir):
     args = argparse.Namespace()
     args.color_cmd = "set"
     args.color = "b_white"
-    args.situation = "no-remote"
+    args.situation = "no_remote"
     with tmpdir.as_cwd():
         csv_config = Path.cwd() / "colors.csv"
         mock_get_fname.return_value = csv_config
@@ -570,11 +579,11 @@ def test_set_color(mock_get_fname, tmpdir):
         items = info.get_color_encoding()
     info.get_color_encoding.cache_clear()  # avoid side effect
     assert items == {
-        "no-remote": "b_white",
-        "in-sync": "green",
+        "no_remote": "b_white",
+        "in_sync": "green",
         "diverged": "red",
-        "local-ahead": "purple",
-        "remote-ahead": "yellow",
+        "local_ahead": "purple",
+        "remote_ahead": "yellow",
     }
 
 
